pub struct Cells { /* private fields */ }Implementations
Sourceimpl Cells
impl Cells
Sourcepub fn iter_collection(&self) -> impl Iterator<Item = &Cell>
pub fn iter_collection(&self) -> impl Iterator<Item = &Cell>
Iterates all Cells in arbitrary order (not sorted).
pub fn get_collection(&self) -> Vec<&Cell>
pub fn is_row_empty(&self, row_num: u32) -> bool
pub fn is_col_empty(&self, col_num: u32) -> bool
Sourcepub fn iter_coordinates_sorted_by_row_column(
&self,
) -> impl Iterator<Item = (u32, u32)> + '_
pub fn iter_coordinates_sorted_by_row_column( &self, ) -> impl Iterator<Item = (u32, u32)> + '_
Iterates all cell coordinates, sorted by row then by column. Coordinate returned is (column, row).
Sourcepub fn iter_cells_sorted_by_row_column(&self) -> impl Iterator<Item = &Cell>
pub fn iter_cells_sorted_by_row_column(&self) -> impl Iterator<Item = &Cell>
Iterates all Cells, sorted by row then by column.
Coordinate returned is (column, row).
Sourcepub fn iter_coordinates_sorted_by_column_row(
&self,
) -> impl Iterator<Item = (u32, u32)> + '_
pub fn iter_coordinates_sorted_by_column_row( &self, ) -> impl Iterator<Item = (u32, u32)> + '_
Iterates all cell coordinates, sorted by column then by row. Coordinate returned is (column, row).
Sourcepub fn iter_cells_sorted_by_column_row(&self) -> impl Iterator<Item = &Cell>
pub fn iter_cells_sorted_by_column_row(&self) -> impl Iterator<Item = &Cell>
Iterates all Cells, sorted by column then by row.
Coordinate returned is (column, row).
pub fn get_collection_sorted(&self) -> Vec<&Cell>
pub fn get_collection_to_hashmap(&self) -> &HashMap<(u32, u32), Box<Cell>>
Sourcepub fn iter_rows_with_cells_by_column(
&self,
column_num: u32,
) -> impl Iterator<Item = u32> + '_
pub fn iter_rows_with_cells_by_column( &self, column_num: u32, ) -> impl Iterator<Item = u32> + '_
Iterates all rows cells in a given column, sorted by the row index.
Sourcepub fn iter_cells_by_column(
&self,
column_num: u32,
) -> impl Iterator<Item = &Cell>
pub fn iter_cells_by_column( &self, column_num: u32, ) -> impl Iterator<Item = &Cell>
Iterates all Cells in a given column, sorted by the row index.
pub fn get_collection_by_column(&self, column_num: &u32) -> Vec<&Cell>
Sourcepub fn iter_columns_with_cells_by_row(
&self,
row_num: u32,
) -> impl Iterator<Item = u32> + '_
pub fn iter_columns_with_cells_by_row( &self, row_num: u32, ) -> impl Iterator<Item = u32> + '_
Iterates all column cells in a given column, sorted by the column index.
Sourcepub fn iter_cells_by_row(&self, row_num: u32) -> impl Iterator<Item = &Cell>
pub fn iter_cells_by_row(&self, row_num: u32) -> impl Iterator<Item = &Cell>
Iterates all Cells in a given column, sorted by the column index.
pub fn get_collection_by_row(&self, row_num: &u32) -> Vec<&Cell>
Sourcepub fn iter_coordinates_by_range_sorted_by_row(
&self,
row_start: u32,
row_end: u32,
col_start: u32,
col_end: u32,
) -> impl Iterator<Item = (u32, u32)> + '_
pub fn iter_coordinates_by_range_sorted_by_row( &self, row_start: u32, row_end: u32, col_start: u32, col_end: u32, ) -> impl Iterator<Item = (u32, u32)> + '_
Iterates all coordinates in a range, sorted by row then by column. Coordinate returned is (column, row).
Sourcepub fn iter_cells_by_range_sorted_by_row(
&self,
row_start: u32,
row_end: u32,
col_start: u32,
col_end: u32,
) -> impl Iterator<Item = &Cell>
pub fn iter_cells_by_range_sorted_by_row( &self, row_start: u32, row_end: u32, col_start: u32, col_end: u32, ) -> impl Iterator<Item = &Cell>
Iterates all Cells in a range, sorted by row then by column.
Sourcepub fn iter_coordinates_by_range_sorted_by_column(
&self,
col_start: u32,
col_end: u32,
row_start: u32,
row_end: u32,
) -> impl Iterator<Item = (u32, u32)> + '_
pub fn iter_coordinates_by_range_sorted_by_column( &self, col_start: u32, col_end: u32, row_start: u32, row_end: u32, ) -> impl Iterator<Item = (u32, u32)> + '_
Iterates all coordinates in a range, sorted by column then by row. Coordinate returned is (column, row).
Sourcepub fn iter_cells_by_range_sorted_by_column(
&self,
col_start: u32,
col_end: u32,
row_start: u32,
row_end: u32,
) -> impl Iterator<Item = &Cell>
pub fn iter_cells_by_range_sorted_by_column( &self, col_start: u32, col_end: u32, row_start: u32, row_end: u32, ) -> impl Iterator<Item = &Cell>
Iterates all Cells in a range, sorted by column then by row.
Coordinate returned is (column, row).
pub fn get_collection_by_column_to_hashmap( &self, column_num: &u32, ) -> HashMap<u32, &Cell>
pub fn get_collection_by_row_to_hashmap( &self, row_num: &u32, ) -> HashMap<u32, &Cell>
pub fn get_highest_column_and_row(&self) -> (u32, u32)
Sourcepub fn has_hyperlink(&self) -> bool
pub fn has_hyperlink(&self) -> bool
Has Hyperlink